@@ -3,6 +3,8 @@ context('plot_imp')
 test_that('plot_imp'
           ,{
             
+  skip_if_not_installed("caret")
+            
   df = mtcars2[, ! names(mtcars2) %in% 'ids' ]
   set.seed(1)
   train = caret::train( disp ~ .
@@ -21,7 +23,9 @@ test_that('plot_imp'
 
 test_that('add_importance_plot'
           ,{
-            
+  
+  skip_if_not_installed("caret")
+                      
   df = mtcars2[, ! names(mtcars2) %in% 'ids' ]
   
   train = caret::train( disp ~ .
@@ -34,7 +38,9 @@ test_that('add_importance_plot'
   
   # we can silence the warning by adjusting bins and labels but we want to 
   # maintain more bins for pred_train
-  expect_warning(p <- alluvial_model_response_caret(train, df, degree = 4, pred_train = pred_train))
+  suppressWarnings({
+    p <- alluvial_model_response_caret(train, df, degree = 4, pred_train = pred_train)
+  })
   
   p_grid = add_marginal_histograms(p, data_input = df, plot = F)
   
